

set -ex



test -L $PREFIX/lib/libnppc.so
test -f $PREFIX/lib/pkgconfig/nppc*.pc
test -f $PREFIX/targets/x86_64-linux/include/npp.h
test -f $PREFIX/targets/x86_64-linux/lib/libnppc.so
test -f $PREFIX/targets/x86_64-linux/lib/stubs/libnppc.so
exit 0
